@@ -1,12 +1,39 @@
 from ._mapi import *
 from ._node import *
 from ._group import _add_elem_2_stGroup
-from ._group import _add_node_2_stGroup
+from ._group import _add_node_2_stGroup,Group
 import numpy as np
-from scipy.interpolate import splev, splprep
+from scipy.interpolate import splev, splprep , interp1d , Akima1DInterpolator
 from math import hypot
 import math
+from ._utils import _convItem2List
 
+def _SInterp(angle,num_points):
+    ''' Angle -> Input list | Num Points -> Output length'''
+
+    angle = _convItem2List(angle)
+    if len(angle) == 1 : 
+        angle.append(angle[0])
+        angle.append(angle[0])
+    if len(angle) == 2 : 
+        angle.append(angle[-1])
+        angle[1] = (angle[0]+angle[2])*0.5
+
+    num_angle = len(angle)
+    angle_intrp_x = [0]
+    angle_intrp_y = [angle[0]]
+    for a in range(num_angle-1):
+        angle_intrp_x.append((a+1)*(num_points-1)/(num_angle-1))
+        angle_intrp_y.append(angle[a+1])
+
+    _alignment = Akima1DInterpolator(angle_intrp_x, angle_intrp_y,method='makima')
+    angle_intrp_func = interp1d(angle_intrp_x, angle_intrp_y)
+
+    angle_intrp_finalY = []
+    for i in range(num_points):
+        angle_intrp_finalY.append(_alignment(i))
+
+    return angle_intrp_finalY
 
 def _interpolateAlignment(pointsArray,n_seg=10,deg=1,mSize=0,includePoint:bool=True) -> list:
     ''' Returns point list and beta angle list'''
@@ -84,6 +111,7 @@ def _interpolateAlignment(pointsArray,n_seg=10,deg=1,mSize=0,includePoint:bool=T
     return align_fine_points
 
 
+
 def _nodeDIST(a:Node,b:Node):
     return round(hypot((a.X-b.X),(a.Y-b.Y),(a.Z-b.Z)),6)
 
@@ -109,6 +137,68 @@ def _triangleAREA(a:Node,b:Node,c:Node):
     mag = np.linalg.norm(np.cross(v1, v2))
     return float(0.5 * mag) , np.cross(v1, v2)/mag
 
+def _calcVector(deltaLocation,angle=0): # Returns normalised local X,Y,Z for line
+    Z_new = np.array([0.000001,0,1])
+    X_new = np.array(deltaLocation)
+    Y_new = np.cross(Z_new, X_new)
+
+    Z_new = np.cross(X_new, Y_new) # Recomputing
+
+    X_new = X_new / (np.linalg.norm(X_new)+0.000001)
+    Y_new = Y_new / (np.linalg.norm(Y_new)+0.000001)
+    Z_new = Z_new / (np.linalg.norm(Z_new)+0.000001)
+
+    from scipy.spatial.transform import Rotation as R
+    p_y = np.array(Y_new)
+    p_z = np.array(Z_new)
+
+    axis = np.array(X_new)
+    theta = np.deg2rad(angle)               # or radians directly
+    rot = R.from_rotvec(axis * theta)           # axis-angle as rotation vector
+    
+    rt_y = rot.apply(p_y)                         # rotated point around axis through origin
+    rt_z = rot.apply(p_z)  
+    
+    return [X_new,rt_y,rt_z]
+
+def _rotatePT(pt,axis,deg):
+    from scipy.spatial.transform import Rotation as R
+    p = np.array(pt)
+    axis = np.array(axis)
+    theta = np.deg2rad(deg)               # or radians directly
+    rot = R.from_rotvec(axis * theta)           # axis-angle as rotation vector
+    return rot.apply(p)                         # rotated point around axis through origin
+
+def _pointOffset(pts,yEcc=0,zEcc=0,angle=0):
+    from ._utils import _matchArray
+
+    angle2 = _matchArray(pts,angle)
+    yEcc2 = _matchArray(pts,yEcc)
+    zEcc2 = _matchArray(pts,zEcc)
+
+    norm = []
+    norm.append(_calcVector(np.subtract(pts[1],pts[0]),angle2[0]))    # first X- along vector
+
+    for i in range(len(pts)-2): # Averaged X- along vector for middle points
+        X_new1 = np.array(np.subtract(pts[i+1],pts[i]))
+        X_new2 = np.array(np.subtract(pts[i+2],pts[i+1]))
+
+        X_new1 = X_new1 / (np.linalg.norm(X_new1)+0.000001)
+        X_new2 = X_new2 / (np.linalg.norm(X_new2)+0.000001)
+
+        norm.append(_calcVector(np.add(X_new1,X_new2),angle2[i+1]))
+
+    norm.append(_calcVector(np.subtract(pts[-1],pts[-2]),angle2[-1])) # last X- along vector
+
+    # print(norm)
+
+    pt_new = []
+    for i in range(len(pts)):
+        pt_new.append(pts[i]+yEcc2[i]*norm[i][1]+zEcc2[i]*norm[i][2])
+
+    return pt_new
+
+
 def _ADD(self):
     """
     Adds an element to the main list. If the ID is 0, it auto-increments.
@@ -258,6 +348,10 @@ class Element:
     ids = []
     __elemDIC__ = {}
 
+    
+    lastLoc = (0,0,0) #Last Location created using Beam element
+    '''Last Node Location created by Beam / Truss element - (x,y,z)'''
+
     @classmethod
     def json(cls):
         json_data = {"Assign": {}}
@@ -291,6 +385,12 @@ class Element:
         Element.elements = []
         Element.ids = []
         Element.__elemDIC__={}
+    
+    @staticmethod
+    def clear():
+        Element.elements = []
+        Element.ids = []
+        Element.__elemDIC__={}
 
     # --- Element Type Subclasses ---
 
@@ -347,6 +447,8 @@ class Element:
                 _norm2 = np.linalg.norm(_n2.AXIS ,axis=1,keepdims=True)
                 _n2.AXIS = _n2.AXIS /_norm2
 
+            Element.lastLoc = (_n2.X,_n2.Y,_n2.Z)
+
             _ADD(self)
 
         @staticmethod
@@ -363,7 +465,7 @@ class Element:
                     locc = s_locc+i*l*unit_vec/n
                     Enode=Node(locc[0].item(),locc[1].item(),locc[2].item())
                     beam_nodes.append(Enode.ID)
-                
+                Element.lastLoc = (locc[0].item(),locc[1].item(),locc[2].item())
                 for i in range(n):
                     if id == 0 : id_new = 0
                     else: id_new = id+i
@@ -385,7 +487,6 @@ class Element:
                 for i in range(n+1):
                     Enode=Node(i_loc[i][0].item(),i_loc[i][1].item(),i_loc[i][2].item())
                     beam_nodes.append(Enode.ID)
-                
                 for i in range(n):
                     if id == 0 : id_new = 0
                     else: id_new = id+i
@@ -395,6 +496,9 @@ class Element:
         
         @staticmethod
         def PLine(points_loc:list,n_div:int=0,deg:int=1,includePoint:bool=True,mat:int=1,sect:int=1,angle:float=0, group = "" , id: int = 0,bLocalAxis=False):
+                '''
+                angle : float of list(float)
+                '''
 
                 beam_nodes =[]
                 beam_obj = []
@@ -402,14 +506,59 @@ class Element:
                     i_loc = points_loc
                 else:
                     i_loc = _interpolateAlignment(points_loc,n_div,deg,0,includePoint)
+
+                num_points = len(i_loc)                
+                angle_intrp_finalY = _SInterp(angle,num_points-1) #Beta Angle to be applied to Elements So, n-1
+
                 for i in i_loc:
                     Enode=Node(i[0],i[1],i[2])
                     beam_nodes.append(Enode.ID)
-                
                 for i in range(len(i_loc)-1):
                     if id == 0 : id_new = 0
                     else: id_new = id+i
-                    beam_obj.append(Element.Beam(beam_nodes[i],beam_nodes[i+1],mat,sect,angle,group,id_new,bLocalAxis))
+                    beam_obj.append(Element.Beam(beam_nodes[i],beam_nodes[i+1],mat,sect,angle_intrp_finalY[i].item(),group,id_new,bLocalAxis))
+                
+                return beam_obj
+        
+        @staticmethod
+        def PLine2(points_loc:list,n_div:int=0,deg:int=1,includePoint:bool=True,mat:int=1,sect:int=1,angle:list[float]=0, group = "" , id: int = 0,bLocalAxis=False,yEcc:list[float]=0,zEcc:list[float]=0,bAngleInEcc:bool=True):
+                '''
+                Creates a polyline with Eccentricity considering the beta angle provided   
+                angle , yEcc , zEcc : float or list(float)   
+                        [0,10] -> Angle at start = 0 | Angle at end = 10   
+                        [0,10,0] -> Angle at start = 0 |  Angle at mid = 10  |  Angle at end = 0   
+                        Inbetween values are **MAKIMA 1D** interpolated. (not cubic)
+                '''
+                from ._utils import _matchArray
+                
+                beam_nodes =[]
+                beam_obj = []
+                if n_div == 0 :
+                    i_loc = points_loc
+                else:
+                    i_loc = _interpolateAlignment(points_loc,n_div,deg,0,includePoint)
+                
+                
+                num_points = len(i_loc)                
+                if bAngleInEcc:
+                    angle_intrp_Ecc = _SInterp(angle,num_points)
+                else:
+                    angle_intrp_Ecc = _matchArray(i_loc,[0])
+                angle_intrp_finalY = _SInterp(angle,num_points-1) #Beta Angle to be applied to Elements So, n-1
+                
+                yEcc_intrp = _SInterp(yEcc,num_points)
+                zEcc_intrp = _SInterp(zEcc,num_points)
+
+                i_loc2 = _pointOffset(i_loc,yEcc_intrp,zEcc_intrp,angle_intrp_Ecc)
+                for i in i_loc2:
+                    Enode=Node(i[0],i[1],i[2])
+                    beam_nodes.append(Enode.ID)
+                
+
+                for i in range(len(i_loc2)-1):
+                    if id == 0 : id_new = 0
+                    else: id_new = id+i
+                    beam_obj.append(Element.Beam(beam_nodes[i],beam_nodes[i+1],mat,sect,angle_intrp_finalY[i].item(),group,id_new,bLocalAxis))
                 
                 return beam_obj
 
@@ -446,7 +595,9 @@ class Element:
             self.NODE = [i, j]
             self.ANGLE = angle
             self._GROUP = group
-            self.LENGTH = _nodeDIST(nodeByID(i),nodeByID(j))
+            _n2 = nodeByID(j)
+            self.LENGTH = _nodeDIST(nodeByID(i),_n2)
+            Element.lastLoc = (_n2.X,_n2.Y,_n2.Z)
             _ADD(self)
 
         @staticmethod
@@ -877,5 +1028,5 @@ def elemByID(elemID:int) -> Element:
     try:
         return (Element.__elemDIC__[str(elemID)])
     except:
-        print(f'There is no element with ID {elemID}')
+        print(Fore.RED +f'There is no element with ID {elemID}'+Style.RESET_ALL)
         return None
