@@ -1,23 +1,54 @@
 import requests
 import sys
-import winreg
-
+from colorama import Fore, Style
+try:import winreg
+except: pass
+import time
+import polars as pl
 
 
 
 def Midas_help():
     """MIDAS Documnetation : https://midas-rnd.github.io/midasapi-python """
-    print("---"*22)
-    print("|   HELP MANUAL : https://midas-rnd.github.io/midasapi-python/   |")
-    print("---"*22,"\n")
-
+    print('\n╭────────────────────────────────────────────────────────────────────────────────────╮')
+    print("│         HELP MANUAL   :     https://midas-rnd.github.io/midasapi-python/           │")
+    print('╰────────────────────────────────────────────────────────────────────────────────────╯\n')
 
 
 
 class NX:
     version_check = True
     user_print = True
-    debug_print = False
+    debug_request = False
+    debug_requestJSON = False
+    debug_response = False
+
+    _symbol_responseCode_ = {
+        "1" : "⌛",
+        "2" : "✅",
+        "3" : "⚠️",
+        "4" : "💀",
+        "5" : "💀"
+    }
+
+
+    @staticmethod
+    def JSToDF_Results(js_json):
+        res_json = {}
+
+        c=0
+        for heading in js_json["SS_Table"]["HEAD"]:
+            for dat in js_json["SS_Table"]["DATA"]:
+                try:
+                    res_json[heading].append(dat[c])
+                except:
+                    res_json[heading]=[]
+                    res_json[heading].append(dat[c])
+
+            c+=1
+
+        res_df = pl.DataFrame(res_json)
+        return(res_df)
     
 
 class MAPI_COUNTRY:
@@ -93,7 +124,6 @@ class MAPI_KEY:
                 my_key = value[0]
                 MAPI_KEY(my_key)
                 print(f' 🔑   MAPI-KEY is taken from Registry entry.  >>  {my_key[:35]}...')
-                print("-"*85)
             except:
                 print(f"🔑   MAPI KEY is not defined. Click on Apps > API Settings to copy the MAPI Key.\n Define it using MAPI_KEY('xxxx')")
                 sys.exit(0)
@@ -124,6 +154,17 @@ def MidasAPI(method:str, command:str, body:dict={})->dict:
         "MAPI-Key": mapi_key
     }
 
+    if MAPI_KEY.count == 1:
+        MAPI_KEY.count =0
+        if NX.user_print:
+            _checkUSER()
+
+
+
+
+    start_time = time.perf_counter()
+
+
     if method == "POST":
         response = requests.post(url=url, headers=headers, json=body)
     elif method == "PUT":
@@ -133,17 +174,26 @@ def MidasAPI(method:str, command:str, body:dict={})->dict:
     elif method == "DELETE":
         response = requests.delete(url=url, headers=headers)
 
-    if response.status_code == 404: 
-        print(f"⚠️  Civil NX model is not connected.  Click on 'Apps> Connect' in Civil NX. \nMake sure the MAPI Key in python code is matching with the MAPI key in Civil NX.\n\n")
-        sys.exit(0)
+    end_time = time.perf_counter()
+    elapsed_time = end_time - start_time
 
-    if NX.debug_print:
-        print(method, command, response.status_code , "✅")
+    if NX.debug_request:
+        # sym = NX._symbol_responseCode_[str(response.status_code)[0]]
+        # print(Fore.RED+f">>   METHOD : {method} |  URL : {command} | STATUS : "+Fore.YELLOW+f" {response.status_code} "+Fore.RED+f"| TIME : {elapsed_time:.4f} sec "+Style.RESET_ALL)
+        print(Fore.RED+f">>   METHOD : {method} |  URL : {command} | STATUS :  {response.status_code} | TIME : {elapsed_time:.4f} sec "+Style.RESET_ALL)
+    if NX.debug_requestJSON:
+        print(Fore.CYAN+">>  "+str(body)+Style.RESET_ALL)
+    if NX.debug_response:
+        print(Fore.GREEN+">>  "+str(response.json())+Style.RESET_ALL)
 
-    if MAPI_KEY.count == 1:
-        if NX.user_print:
-            MAPI_KEY.count = 0
-            _checkUSER()
+    if MAPI_KEY.count == 0:
+        MAPI_KEY.count = -1
+        if response.status_code == 404:
+            print(Fore.RED +'\n╭─ 💀   ─────────────────────────────────────────────────────────────────────────────╮')
+            print(f"│  Civil NX model is not connected.  Click on 'Apps > Connect' in Civil NX.          │")
+            print(f"│  Make sure the MAPI Key in python code is matching with the MAPI key in Civil NX.  │")
+            print('╰────────────────────────────────────────────────────────────────────────────────────╯\n'+Style.RESET_ALL)
+            sys.exit(0)
     
 
 
@@ -167,8 +217,25 @@ def _setUNIT(unitJS):
 def _checkUSER():
     try:
         resp =  MidasAPI('GET','/config/ver',{})['VER']
-        print(f"Connected to {resp['NAME']}   🟢")
-        print(f"USER : {resp['USER']}    |   COMPANY : {resp['COMPANY']}")
-        print("-"*85)
+
+        # print(f"{' '*15}Connected to {resp['NAME']}")
+        # print(f"{' '*15}USER : {resp['USER']}          COMPANY : {resp['COMPANY']}")
+
+        ln1 = f"Connected to {resp['NAME']}"
+        ln2 = f"USER : {resp['USER']}          COMPANY : {resp['COMPANY']}"
+
+        lg_ln1 = 63-len(ln1)
+        lg_ln2 = 67-len(ln2)
+
+        line1 = f"│{' '*15} {ln1} {' '*lg_ln1} 🟢 │"
+        line2 = f"│{' '*15} {ln2} {' '*lg_ln2}│"
+        print(Fore.GREEN+'\n╭─ 🔔  ──────────────────────────────────────────────────────────────────────────────╮')
+        print(line1)
+        print(line2)
+        print('╰────────────────────────────────────────────────────────────────────────────────────╯\n'+Style.RESET_ALL)
+
+
+        # print('─'*86)
+
     except:
-        print("")
\ No newline at end of file
+        pass
\ No newline at end of file
