@@ -2,6 +2,7 @@
 from ._mapi import *
 from ._utils import *
 from ._load import *
+from ._group import *
 
 
 def _JStoObj_Relax(js):
@@ -760,7 +761,7 @@ class Tendon:
                             array_temp.append({
                                     'PT' : [self.P_XYZ[j].X,self.P_XYZ[j].Y,self.P_XYZ[j].Z],
                                     'bFIX' : self.bFIX[j],
-                                    'R' : self.RADIUS[j]
+                                    'RADIUS' : self.RADIUS[j]
                             })
                     else:
                         for j in range(len(self.P_XYZ)):
@@ -771,6 +772,8 @@ class Tendon:
                             })
                     
                     
+                    
+                    
                     # --- 3D Main ----
 
                     json_prof = {
