@@ -1,5 +1,5 @@
-from ._model import *
-from ._mapi import *
+# from ._model import *
+# from ._mapi import *
 
 #Function to remove duplicate set of values from 2 lists
 # def unique_lists(li1, li2):
@@ -28,6 +28,7 @@ from ._mapi import *
 #     return(b)
 #---------------------------------------------------------------------------------------------------------------
 
+import numpy as np
 
 def sFlatten(list_of_list):
     # list_of_list = [list_of_list]
@@ -84,6 +85,16 @@ def zz_add_to_dict(dictionary, key, value):
 
 
 def _convItem2List(item):
-    if isinstance(item,list):
+    if isinstance(item,(list,np.ndarray)):
         return item
     return [item]
+
+def _matchArray(A,B):
+    '''Matches B to length of A   
+    Return B'''
+    A = _convItem2List(A)
+    B = _convItem2List(B)
+    n = len(A)
+    if len(B) >= n:
+        return B[:n]
+    return B + [B[-1]] * (n - len(B))
